@@ -1,6 +1,10 @@
 #include "list/tracks.hpp"
+
 #include "mainwindow.hpp"
+#include "metatypes.hpp"
 #include "dialog/createplaylist.hpp"
+#include "listitem/track.hpp"
+#include "util/datetime.hpp"
 #include "util/shortcut.hpp"
 
 #include <QShortcut>
